4.12. umbra.components.factory.componentsManagerUi.nodes — Umbra 1.0.9 documentation

# 4.12. umbra.components.factory.componentsManagerUi.nodes

nodes.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `umbra.components.factory.componentsManagerUi.componentsManagerUi.ComponentsManagerUi` Component Interface class nodes.

Others:

## 4.12.1. Module Attributes

`umbra.components.factory.componentsManagerUi.nodes.` `LOGGER`

## 4.12.2. Classes

class `umbra.components.factory.componentsManagerUi.nodes.` `PathNode`(name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  Defines `umbra.components.factory.componentsManagerUi.componentsManagerUi.ComponentsManagerUi`
    Component Interface class Model path node.

  Initializes the class.

  Parameters: | name (unicode) – Node name. parent (GraphModelNode) – Node parent. children (list) – Children. roles (dict) – Roles. nodeFlags (int) – Node flags. attributesFlags (int) – Attributes flags. **kwargs (**) – Keywords arguments.

class `umbra.components.factory.componentsManagerUi.nodes.` `ComponentNode`(component, name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  Defines `umbra.components.factory.componentsManagerUi.componentsManagerUi.ComponentsManagerUi` Component Interface class Model component node.

  Initializes the class.

  Parameters: | component (Component or QWidgetComponent or QObjectComponent) – Component. name (unicode) – Node name. parent (GraphModelNode) – Node parent. children (list) – Children. roles (dict) – Roles. nodeFlags (int) – Node flags. attributesFlags (int) – Attributes flags. **kwargs (**) – Keywords arguments.

  `component`

    Property for self.__component attribute.

    Returns: | self.__component.
    Return type: | Component or QWidgetComponent or QObjectComponent

  `toolTipText`

    Property for self.__toolTipText attribute.

    Returns: | self.__toolTipText.
    Return type: | unicode

  `updateToolTip`()

    Updates the node tooltip.

    Returns: | Method success.
    Return type: | bool